"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  AuthenticationProvider: () => AuthenticationProvider_default,
  useAccount: () => useUserAccount_default,
  useAuthenticated: () => useAuthenticated_default,
  useAuthentication: () => useMsalAuthentication_default
});
module.exports = __toCommonJS(src_exports);

// src/AuthenticationProvider.tsx
var import_react4 = __toESM(require("react"));
var import_msal_browser3 = require("@azure/msal-browser");
var import_msal_react2 = require("@azure/msal-react");

// src/hooks/useConfiguration.ts
var import_react = require("react");
var import_msal_browser = require("@azure/msal-browser");

// src/configs/index.ts
var environmentConfig = () => ({
  clientId: process.env["VITE_MSAL_CLIENT_ID"],
  authority: process.env["VITE_MSAL_AUTHORITY"],
  loginRedirectUri: process.env["VITE_MSAL_REDIRECT_URL"],
  logoutRedirectUri: process.env["VITE_MSAL_LOGOUT_REDIRECT_URL"],
  scopes: process.env["VITE_MSAL_SCOPES"],
  cacheLoc: process.env["VITE_MSAL_CACHE_LOCATION"],
  tokenInterval: process.env["VITE_MSAL_TOKEN_INTERVAL"],
  tokenThreshold: process.env["VITE_MSAL_TOKEN_REFRESH_THRESHOLD"]
});
var Constants = {
  SPLIT_COMMA: ",",
  TOKEN_INTERVAL: 36e5,
  TOKEN_THRESHOLD: 300,
  SCOPES: ["User.Read"]
};
var ConstantsMessage = {
  MSG_ENV: "Missing environment configuration",
  MSG_CLIENT_ID: "Missing clientId",
  MSG_AUTH_URL: "Missing authority url",
  MSG_REDIRECT_URL: "Missing redirect url"
};

// src/hooks/useConfiguration.ts
var useConfiguration = (authConfig) => {
  const [config, setConfig] = (0, import_react.useState)();
  const [options, setOptions] = (0, import_react.useState)();
  (0, import_react.useEffect)(() => {
    if (authConfig != null && authConfig.option) {
      setOptions(authConfig.option);
    }
    const clientInstance = authConfig && authConfig.instance ? authConfig.instance : defaultInstance();
    const msalInstance = new import_msal_browser.PublicClientApplication(clientInstance);
    if (msalInstance) {
      setConfig(msalInstance);
    }
  }, [authConfig]);
  const defaultInstance = () => {
    const env = environmentConfig();
    if (!env)
      throw new Error(ConstantsMessage.MSG_ENV);
    let interval = Constants.TOKEN_INTERVAL;
    let threshold = Constants.TOKEN_THRESHOLD;
    let cacheLoc = import_msal_browser.BrowserCacheLocation.LocalStorage;
    if (!env.clientId) {
      throw new Error(ConstantsMessage.MSG_CLIENT_ID);
    }
    if (!env.authority) {
      throw new Error(ConstantsMessage.MSG_AUTH_URL);
    }
    if (!env.loginRedirectUri) {
      throw new Error(ConstantsMessage.MSG_REDIRECT_URL);
    }
    if (env.tokenInterval) {
      interval = parseInt(env.tokenInterval);
    }
    if (env.tokenThreshold) {
      threshold = parseInt(env.tokenInterval);
    }
    if (env.cacheLoc) {
      cacheLoc = import_msal_browser.BrowserCacheLocation[env.cacheLoc];
    }
    setOptions({
      scopes: env.scopes?.split(Constants.SPLIT_COMMA),
      tokenInterval: interval,
      tokenThreshold: threshold
    });
    const defaultConfig = {
      auth: {
        clientId: env.clientId,
        authority: env.authority,
        redirectUri: env.loginRedirectUri,
        postLogoutRedirectUri: env.logoutRedirectUri,
        navigateToLoginRequestUrl: false
      },
      cache: {
        cacheLocation: cacheLoc,
        storeAuthStateInCookie: true
      },
      system: {
        tokenRenewalOffsetSeconds: Constants.TOKEN_THRESHOLD
      }
    };
    return defaultConfig;
  };
  return { config, option: options };
};
var useConfiguration_default = useConfiguration;

// src/components/AuthenticationSuccess.tsx
var import_react3 = __toESM(require("react"));

// src/hooks/useUserAccount.ts
var import_msal_react = require("@azure/msal-react");
var import_msal_browser2 = require("@azure/msal-browser");
var import_jwt_decode = require("jwt-decode");
var import_react_framework = require("react.framework.userclaim");
var import_react2 = require("react");
var useUserAccount = () => {
  const { instance, accounts } = (0, import_msal_react.useMsal)();
  const authentication = (0, import_react2.useContext)(AuthenticationContext);
  const { setUserToken, getTokenInfo } = (0, import_react_framework.useUserTokenService)();
  const { setUserClaims, getUserClaim } = (0, import_react_framework.useUserClaimService)();
  const { setUserInfo } = (0, import_react_framework.useUserService)();
  const getUserToken = async () => {
    const token = getTokenInfo();
    if (token)
      return token;
    const accountInfo = await getAcquireTokenSilent();
    if (accountInfo)
      setUserTokenToStore(accountInfo);
    return accountInfo?.accessToken;
  };
  const getAccessToken = async (scopes, key) => {
    const tokenInfo = getUserClaim(key, "");
    if (tokenInfo && tokenInfo != null)
      return tokenInfo.value;
    const accountInfo = await getAcquireTokenSilent(scopes);
    if (accountInfo) {
      const userClaims = [
        { key, value: accountInfo.accessToken ?? "" }
      ];
      setUserClaims(userClaims);
      return accountInfo.accessToken;
    }
    return null;
  };
  const getAcquireTokenSilent = async (scopes) => {
    const authRequest = { account: accounts[0], scopes: Constants.SCOPES };
    if (scopes != null && scopes.length > 0) {
      authRequest.scopes = scopes;
    }
    try {
      const response = await instance.acquireTokenSilent(authRequest);
      return response;
    } catch (err) {
      if (err instanceof import_msal_browser2.InteractionRequiredAuthError) {
        await instance.acquireTokenRedirect(authRequest);
      }
    }
  };
  const setAccountInfoToStore = (accountInfo) => {
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
      setAccessTokenToStore(accountInfo.accessToken);
      const userAccountExtent = accountInfo.account;
      if (userAccountExtent) {
        const userClaims = [
          { key: "name", value: userAccountExtent.name ?? "" },
          { key: "username", value: userAccountExtent.username ?? "" }
        ];
        setUserClaims(userClaims);
      }
    }
  };
  const setUserTokenToStore = (accountInfo) => {
    if (accountInfo) {
      const userToken = {
        tokenId: accountInfo.tokenId,
        refreshToken: accountInfo.accessToken,
        tokenExpirationDate: accountInfo.expiresOn,
        userToken: accountInfo.accessToken
      };
      setUserToken(userToken);
    }
  };
  const setAccessTokenToStore = (accessToken) => {
    if (accessToken) {
      const decodeToken = (0, import_jwt_decode.jwtDecode)(accessToken);
      if (decodeToken) {
        const user = {
          id: 1,
          email: decodeToken.upn,
          firstname: decodeToken.family_name,
          lastName: decodeToken.given_name,
          name: decodeToken.name
        };
        setUserInfo(user);
      }
    }
  };
  const setAcquireTokenToStore = async () => {
    const scopes = authentication?.option?.scopes;
    const accountInfo = await getAcquireTokenSilent(scopes);
    if (accountInfo) {
      setAccountInfoToStore(accountInfo);
    }
  };
  const setUserActiveAccount = async () => {
    const currentAccounts = instance.getAllAccounts();
    if (currentAccounts.length > 0) {
      instance.setActiveAccount(currentAccounts[0]);
    }
    setAcquireTokenToStore();
  };
  const refreshAccessToken = async () => {
    const threshold = authentication?.option?.tokenThreshold ?? Constants.TOKEN_THRESHOLD;
    const isExpired = await isTokenExpired(threshold);
    if (!isExpired) {
      setAcquireTokenToStore();
    }
  };
  const isTokenExpired = async (tokenThreshold) => {
    let isExpired = false;
    const token = getTokenInfo();
    if (token) {
      const decodeToken = (0, import_jwt_decode.jwtDecode)(token);
      if (decodeToken.exp) {
        const currentTime = Math.floor(Date.now() / 1e3);
        const timeUntilExpiry = decodeToken.exp - currentTime;
        isExpired = timeUntilExpiry <= (tokenThreshold ?? 0);
      }
    }
    return isExpired;
  };
  return { getUserToken, getAccessToken, refreshAccessToken, setUserActiveAccount };
};
var useUserAccount_default = useUserAccount;

// src/components/AuthenticationSuccess.tsx
var AuthenticationSuccess = ({ children }) => {
  const authentication = (0, import_react3.useContext)(AuthenticationContext);
  const { setUserActiveAccount, refreshAccessToken } = useUserAccount_default();
  (0, import_react3.useEffect)(() => {
    setUserActiveAccount();
    const option = authentication?.option;
    const interval = setInterval(refreshAccessToken, option?.tokenInterval);
    return () => clearInterval(interval);
  }, []);
  return /* @__PURE__ */ import_react3.default.createElement(import_react3.default.Fragment, null, children);
};
var AuthenticationSuccess_default = AuthenticationSuccess;

// src/AuthenticationProvider.tsx
var AuthenticationContext = (0, import_react4.createContext)(null);
var AuthenticationProvider = ({ children, beforeAuthComponent, authConfig }) => {
  const { config, option } = useConfiguration_default(authConfig);
  return config != null ? /* @__PURE__ */ import_react4.default.createElement(import_msal_react2.MsalProvider, { instance: config }, beforeAuthComponent ? /* @__PURE__ */ import_react4.default.createElement(import_react4.default.Fragment, null, /* @__PURE__ */ import_react4.default.createElement(import_msal_react2.UnauthenticatedTemplate, null, beforeAuthComponent), /* @__PURE__ */ import_react4.default.createElement(import_msal_react2.AuthenticatedTemplate, null, /* @__PURE__ */ import_react4.default.createElement(AuthenticationContext.Provider, { value: { option } }, /* @__PURE__ */ import_react4.default.createElement(AuthenticationSuccess_default, null, children)))) : /* @__PURE__ */ import_react4.default.createElement(import_react4.default.Fragment, null, /* @__PURE__ */ import_react4.default.createElement(import_msal_react2.MsalAuthenticationTemplate, { authenticationRequest: { scopes: option?.scopes }, interactionType: import_msal_browser3.InteractionType.Redirect }, /* @__PURE__ */ import_react4.default.createElement(AuthenticationContext.Provider, { value: { option } }, /* @__PURE__ */ import_react4.default.createElement(AuthenticationSuccess_default, null, children))))) : null;
};
var AuthenticationProvider_default = AuthenticationProvider;

// src/hooks/useMsalAuthentication.ts
var import_msal_react3 = require("@azure/msal-react");
var useMsalAuthentication = () => {
  const { instance } = (0, import_msal_react3.useMsal)();
  const loginRedirect = () => {
    instance.loginRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const loginPopup = () => {
    instance.loginPopup().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutRedirect = () => {
    instance.logoutRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutPopup = () => {
    instance.logoutPopup({
      account: instance.getActiveAccount()
    }).catch((error) => {
      throw new Error(error);
    });
  };
  return { loginRedirect, loginPopup, logoutRedirect, logoutPopup };
};
var useMsalAuthentication_default = useMsalAuthentication;

// src/hooks/useAuthenticated.ts
var import_msal_react4 = require("@azure/msal-react");
var useAuthenticated = () => {
  const isAuthenticated = (0, import_msal_react4.useIsAuthenticated)();
  return isAuthenticated;
};
var useAuthenticated_default = useAuthenticated;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  AuthenticationProvider,
  useAccount,
  useAuthenticated,
  useAuthentication
});
